.. Copyright 2021 CMakePP
..
.. Licensed under the Apache License, Version 2.0 (the "License");
.. you may not use this file except in compliance with the License.
.. You may obtain a copy of the License at
..
.. http://www.apache.org/licenses/LICENSE-2.0
..
.. Unless required by applicable law or agreed to in writing, software
.. distributed under the License is distributed on an "AS IS" BASIS,
.. WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
.. See the License for the specific language governing permissions and
.. limitations under the License.
..
#######################
Developer Documentation
#######################

The following documentation topics are meant primarily for developers working on
CMinx. It is our hope that these topics will make it easier to dive into the
CMinx project and to recall why we made the design decisions we did.

-----------------
Table of Contents
-----------------

.. toctree::
   :maxdepth: 2

   repo_structure
   dependencies
   overview
   api
   documentation
   ci
